==> QLC%2B_4.12.6.tar.gz: qlcplus-QLC-_4.12.6/plugins/E1.31/E131_cz_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>ConfigureE131</name>
    <message>
        <location filename="configuree131.ui" line="33"/>
        <source>Configure E1.31 Plugin</source>
        <translation>Konfigurace E1.31 pluginu</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="43"/>
        <source>Universes Configuration</source>
        <translation>Konfigurace větví</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="56"/>
        <source>Interface</source>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="66"/>
        <source>Multicast</source>
        <translation>Skupinové vysílání (multicast)</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="71"/>
        <source>IP Address</source>
        <translation>IP adresa</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="76"/>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="81"/>
        <source>E1.31 Universe</source>
        <translation>Větev E1.31</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="86"/>
        <source>Transmission Mode</source>
        <translation>Spůsob přenosu</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="91"/>
        <source>Priority</source>
        <translation>Priorita</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="61"/>
        <source>Universe</source>
        <translation>Větev</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="86"/>
        <source>Inputs</source>
        <translation>Vstupy</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="92"/>
        <source>Outputs</source>
        <translation>Výstupy</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="176"/>
        <source>Full</source>
        <translation>Plný</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="177"/>
        <source>Partial</source>
        <translation>Částečný</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="185"/>
        <source>%1 - min, %2 - default, %3 - max</source>
        <translation>%1 - nejnižší, %2 - základní, %3 - nejvyšší</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="216"/>
        <source>Invalid IP</source>
        <translation>Neplatná IP adresa</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="216"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 není platná IP adresa.
Prosím opravte zadání před potvrzením.</translation>
    </message>
</context>
<context>
    <name>E131Plugin</name>
    <message>
        <location filename="e131plugin.cpp" line="93"/>
        <source>This plugin provides DMX output for devices supporting the E1.31 communication protocol.</source>
        <translation>Tento plugin umožňuje podporu DMX výstupu pro zařízení podporující komunikační protokol E1.31.</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="140"/>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="144"/>
        <location filename="e131plugin.cpp" line="284"/>
        <source>Status: Not open</source>
        <translation>Stav: Není otevřen</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="147"/>
        <location filename="e131plugin.cpp" line="287"/>
        <source>Status: Open</source>
        <translation>Stav: Otevřen</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="149"/>
        <source>Packets sent: </source>
        <translation>Odeslané pakety:</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="280"/>
        <source>Input</source>
        <translation>Vstup</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="289"/>
        <source>Packets received: </source>
        <translation>Přijaté pakety:</translation>
    </message>
</context>
</TS>

==> QLC%2B_4.14.0.tar.gz: qlcplus-QLC-_4.14.0/plugins/E1.31/E131_cz_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>ConfigureE131</name>
    <message>
        <location filename="configuree131.ui" line="33"/>
        <source>Configure E1.31 Plugin</source>
        <translation>Konfigurace E1.31 pluginu</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="43"/>
        <source>Universes Configuration</source>
        <translation>Konfigurace větví</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="56"/>
        <source>Interface</source>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="66"/>
        <source>Multicast</source>
        <translation>Skupinové vysílání (multicast)</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="71"/>
        <source>IP Address</source>
        <translation>IP adresa</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="76"/>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="81"/>
        <source>E1.31 Universe</source>
        <translation>Větev E1.31</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="86"/>
        <source>Transmission Mode</source>
        <translation>Spůsob přenosu</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="91"/>
        <source>Priority</source>
        <translation>Priorita</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="101"/>
        <source>Seconds to wait for an interface to be ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="61"/>
        <source>Universe</source>
        <translation>Větev</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="99"/>
        <source>Inputs</source>
        <translation>Vstupy</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="105"/>
        <source>Outputs</source>
        <translation>Výstupy</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="189"/>
        <source>Full</source>
        <translation>Plný</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="190"/>
        <source>Partial</source>
        <translation>Částečný</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="198"/>
        <source>%1 - min, %2 - default, %3 - max</source>
        <translation>%1 - nejnižší, %2 - základní, %3 - nejvyšší</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="245"/>
        <source>Invalid IP</source>
        <translation>Neplatná IP adresa</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="245"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 není platná IP adresa.
Prosím opravte zadání před potvrzením.</translation>
    </message>
</context>
<context>
    <name>E131Plugin</name>
    <message>
        <location filename="e131plugin.cpp" line="97"/>
        <source>This plugin provides DMX output for devices supporting the E1.31 communication protocol.</source>
        <translation>Tento plugin umožňuje podporu DMX výstupu pro zařízení podporující komunikační protokol E1.31.</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="144"/>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="148"/>
        <location filename="e131plugin.cpp" line="287"/>
        <source>Status: Not open</source>
        <translation>Stav: Není otevřen</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="151"/>
        <location filename="e131plugin.cpp" line="290"/>
        <source>Status: Open</source>
        <translation>Stav: Otevřen</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="153"/>
        <source>Packets sent: </source>
        <translation>Odeslané pakety:</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="283"/>
        <source>Input</source>
        <translation>Vstup</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="292"/>
        <source>Packets received: </source>
        <translation>Přijaté pakety:</translation>
    </message>
</context>
</TS>
